@@ -7,7 +7,6 @@
 
 import json
 import socket
-import sys
 import time
 import zipfile
 from collections.abc import Iterator, Mapping
@@ -21,49 +20,14 @@ from paramiko import SFTPClient, SSHClient, ssh_exception
 
 XOCHITL_DIR = Path(".local/share/remarkable/xochitl")
 
-CFG_FILE = Path("~/.config/qrm.cfg")
 
-
-def load_json(path: Path) -> Any:
-    """Convenience wrapper for reading a JSON file"""
-    with suppress(FileNotFoundError, json.JSONDecodeError):
-        with open(path.expanduser()) as file:
-            return json.load(file)
-    return {}
-
-
-def save_json(path: Path, data: Any) -> None:
-    """Convenience wrapper for writing a JSON file"""
-    with open(path.expanduser(), "w") as file:
-        json.dump(data, file)
-
-
-def load_config_or_defaults() -> Any:
-    """Convenience convenience wrapper for getting stored contents or default values"""
-    return {
-        **{
-            "auth": {
-                "host": "reMarkable",
-                "username": "root",
-                "password": "---",
-            }
-        },
-        **load_json(CFG_FILE),
-    }
-
-
-def save_config(data: Any) -> None:
-    """Convenience convenience wrapper for storing the configuration to where it belongs"""
-    save_json(CFG_FILE, data)
-
-
-def ssh_connection(host: str, username: str, password:str|None=None, timeout:int=6) -> SSHClient:
+def ssh_connection(config) -> SSHClient:
     """Establishes and returns a paramiko SSH client session"""
     client = SSHClient()
     client.load_system_host_keys()
     try:
-        print(f"Try to connect to {host!r}...")
-        client.connect(host, username=username, password=password, timeout=timeout)
+        print(f"Try to connect to {config.hostname!r}...")
+        client.connect(config.hostname, username=config.username, password=config.password, timeout=config.timeout)
         return client
     except socket.gaierror as exc:
         raise RuntimeError(f"{exc}") from exc
@@ -132,11 +96,11 @@ def upload_file(rm_sftp: SFTPClient, path: Path) -> None:
 
     uuid = uuid4()
 
-    print(f"{time.time() - t}")
+    print(f"{time.time() - t:.2f}s")
 
     print(f"{uuid}")
 
-    print(f"{time.time() - t}")
+    print(f"{time.time() - t:.2f}s")
     with path.open("rb") as inputfile:
         with rm_sftp.open(str(XOCHITL_DIR / f"{uuid}.epub"), "wb") as payloadfile:
             payloadfile.write(inputfile.read())
@@ -145,7 +109,7 @@ def upload_file(rm_sftp: SFTPClient, path: Path) -> None:
     with rm_sftp.open(str(XOCHITL_DIR / f"{uuid}.content"), "w") as contentfile:
         json.dump({"coverPageNumber": 0, "fileType": "epub"}, contentfile)
 
-    print(f"{time.time() - t}")
+    print(f"{time.time() - t:.2f}s")
 
     with rm_sftp.open(str(XOCHITL_DIR / f"{uuid}.metadata"), "w") as metadatafile:
         json.dump(
@@ -166,10 +130,6 @@ def upload_file(rm_sftp: SFTPClient, path: Path) -> None:
             metadatafile,
         )
 
-    # print(f"{time.time() - t}")
-
-    # print(f"{time.time() - t}")
-
 
 def reboot(client: SSHClient) -> None:
     """Shortcut for rebooting the device"""
