@@ -20,46 +20,50 @@ def log() -> logging.Logger:
     return logging.getLogger("qrm_ui")
 
 
-class RmConnectWindow(QtWidgets.QMainWindow):
+class QrMWindow(QtWidgets.QMainWindow):
     """The one and only application window"""
 
-    def __init__(self) -> None:
+    def __init__(self, config) -> None:
         super().__init__()
+        self.config = config
         self.rm_ftp = None
+        self.rm_ssh = None
         uic.loadUi(Path(__file__).parent / "qrm.ui", self)
         self.documents.horizontalHeader().setStretchLastSection(True)
         self.setAcceptDrops(True)
 
-        self.config = qrm_common.load_json(qrm_common.CFG_FILE)
-        auth = self.config.setdefault("auth", {})
-
-        self.txt_host.setText(auth.setdefault("host", "reMarkable"))
-        self.txt_username.setText(auth.setdefault("username", "root"))
-        self.txt_password.setText(auth.setdefault("password", "---"))
-        self.txt_host.textChanged.connect(self.on_txt_host_textChanged)
+        self.txt_hostname.setText(config.hostname)
+        self.txt_username.setText(config.username)
+        self.txt_password.setText(config.password)
+        self.txt_hostname.textChanged.connect(self.on_txt_hostname_textChanged)
         self.txt_username.textChanged.connect(self.on_txt_username_textChanged)
         self.txt_password.textChanged.connect(self.on_txt_password_textChanged)
         self.pb_connect.clicked.connect(self.connect)
         self.pb_reboot.clicked.connect(self.on_pb_reboot_clicked)
         self.pb_reboot.setEnabled(False)
 
-        self.setGeometry(*self.config.get("window_geometry", (50, 50, 1000, 500)))
+        if config.window_geometry:
+            self.setGeometry(*config.window_geometry)
+
         self.show()
 
-    def on_txt_host_textChanged(self, text: str) -> None:
+    def on_txt_hostname_textChanged(self, text: str) -> None:
         """React on hostname modification"""
-        self.config["auth"]["host"] = text
+        self.config.hostname = text
 
     def on_txt_username_textChanged(self, text: str) -> None:
         """React on username modification"""
-        self.config["auth"]["username"] = text
+        self.config.username = text
 
     def on_txt_password_textChanged(self, text: str) -> None:
         """React on password modification"""
-        self.config["auth"]["password"] = text
+        self.config.password = text
 
-    def on_pb_reboot_clicked(bool) -> None:
+    def on_pb_reboot_clicked(self) -> None:
         """React on reboot button click"""
+        if self.rm_ssh:
+            qrm_common.reboot(self.rm_ssh)
+
 
     @QtCore.pyqtSlot()
     def connect(self) -> None:
@@ -67,16 +71,12 @@ class RmConnectWindow(QtWidgets.QMainWindow):
         self.pb_reboot.setEnabled(False)
 
         try:
-            rm_ssh = qrm_common.ssh_connection(
-                host=self.config["auth"]["host"],
-                username=self.config["auth"]["username"],
-                password=self.config["auth"]["password"],
-            )
+            self.rm_ssh = qrm_common.ssh_connection(self.config)
         except RuntimeError as exc:
             print(f"Connection failed: {exc}")
             return
 
-        self.rm_ftp = qrm_common.sftp_connection(rm_ssh)
+        self.rm_ftp = qrm_common.sftp_connection(self.rm_ssh)
         self.pb_reboot.setEnabled(True)
         self.populate()
 
@@ -134,22 +134,14 @@ class RmConnectWindow(QtWidgets.QMainWindow):
         """save state before shutting down"""
         logging.info("got some closish signal, bye")
         geom = self.geometry()
-        qrm_common.save_json(
-            qrm_common.CFG_FILE,
-            {
-                **self.config,
-                **{
-                    "window_geometry": (geom.x(), geom.y(), geom.width(), geom.height()),
-                },
-            },
-        )
+        self.config.window_geometry = (geom.x(), geom.y(), geom.width(), geom.height())
 
 
-def main() -> None:
+def main(args) -> None:
     """Typical PyQt5 boilerplate main entry point"""
     logging.getLogger().setLevel(logging.INFO)
     app = QtWidgets.QApplication(sys.argv)
-    window = RmConnectWindow()
+    window = QrMWindow(args)
 
     for s in (signal.SIGABRT, signal.SIGINT, signal.SIGSEGV, signal.SIGTERM):
         signal.signal(s, lambda signal, frame: window.close())
@@ -159,7 +151,7 @@ def main() -> None:
     timer.start(200)
     timer.timeout.connect(lambda: None)
 
-    sys.exit(app.exec_())
+    app.exec_()
 
 
 if __name__ == "__main__":
